==> punctilious-1.0.7.tar.gz: punctilious-1.0.7/README.md <==
# punctilious

<br />
<div align="center">
  <a href="https://github.com/daviddoret/punctilious">
    <img src="https://github.com/daviddoret/punctilious/raw/master/branding/punctilious-logo-full-light-600x600-white.png" alt="The punctilious logo" width="300" height="300">
  </a>
</div>
<p align="center">
    A human-friendly and developer-friendly math proof assistant library.
</p>

## About

*Punctilious* is a *math proof assistant* open-source project developed in python. In straightforward language, it
intends to
facilitate the study and development of mathematical proofs by human beings.

There exists multiple math proof assistants, including:

* [Coq](https://coq.inria.fr/)
* [Isabelle](https://isabelle.in.tum.de/)
* [Lean](https://leanprover.github.io/)

...and many more. The [proof assistant](https://en.wikipedia.org/wiki/Proof_assistant) page on Wikipedia contains a
general-purpose comparison of these.

In contrast, *punctilious* is a ridiculous [Lilliputian](https://en.wikipedia.org/wiki/Lilliput_and_Blefuscu) with
neither the length, nor the breadth of these time-proven systems.

### So why develop yet another math proof assistant?

Besides being a fun and thrilling learning experience, the focus points of *punctilious* are:

* Human-friendly and developer-friendly inputs (i.e.: write math as we learn it)
* Ease of use
* Human-friendly and developer-friendly outputs (i.e.: readable)

*Punctilious* does not pay much attention to:

* Performance (i.e. for large-scale proof applications)

## Source code repository

*Punctilious* source code lives on [GitHub](https://github.com/) here:
<p align="center">
[https://github.com/daviddoret/punctilious](https://github.com/daviddoret/punctilious)
</p>

## Package directory

The *punctilious* package is available for download from the [Python Package Index (PyPi)](https://pypi.org/) here:
<p align="center">
[https://pypi.org/project/punctilious/](https://pypi.org/project/punctilious/)
</p>

## Prerequisites

Python version 3.11 or later.

## Installation

Install the latest version of the *punctilious* package, or upgrade it to the latest version if already installed:

```console
pip install punctilious --upgrade
```

## Getting started

A series of samples will be provided soon once we will have published our documentation on ReadTheDocs. Please wait...

## Documentation

*Punctilious* documentation lives on [ReadTheDocs](https://punctilious.readthedocs.io/en/latest/).

## More links

* [Roadmap](https://punctilious.readthedocs.io/en/latest/front_matter/roadmap_front_matter.html)
* [Contributing](https://punctilious.readthedocs.io/en/latest/front_matter/contributing_front_matter.html)
* [Project](https://punctilious.readthedocs.io/en/latest/front_matter/project_front_matter.html)
* [License](https://github.com/daviddoret/punctilious/blob/master/LICENSE)

## Acknowledgments

The list of dependencies is being compiled. Please wait...

==> punctilious-1.0.9.tar.gz: punctilious-1.0.9/README.md <==
# punctilious

<br />
<div align="center">
  <a href="https://github.com/daviddoret/punctilious">
    <img src="https://github.com/daviddoret/punctilious/raw/master/branding/punctilious-logo-full-light-600x600-white.png" alt="The punctilious logo" width="300" height="300">
  </a>
</div>
<p align="center">
    A human-friendly and developer-friendly math proof assistant library.
</p>

## About

*Punctilious* is a *math proof assistant* open-source project developed in python. In straightforward language, it
intends to
facilitate the study and development of mathematical proofs by human beings.

There exists multiple math proof assistants, including:

* [Coq](https://coq.inria.fr/)
* [Isabelle](https://isabelle.in.tum.de/)
* [Lean](https://leanprover.github.io/)

...and many more. The [proof assistant](https://en.wikipedia.org/wiki/Proof_assistant) page on Wikipedia contains a
general-purpose comparison of these.

In contrast, *punctilious* is a ridiculous [Lilliputian](https://en.wikipedia.org/wiki/Lilliput_and_Blefuscu) with
neither the length, nor the breadth of these time-proven systems.

### So why develop yet another math proof assistant?

Besides being a fun and thrilling learning experience, the focus points of *punctilious* are:

* Human-friendly and developer-friendly inputs (i.e.: write math as we learn it)
* Ease of use
* Human-friendly and developer-friendly outputs (i.e.: readable)

*Punctilious* does not pay much attention to:

* Performance (i.e. for large-scale proof applications)

## Source code repository

The source code of the *punctilious* package lives on [GitHub](https://github.com/) here:
<p align="center"><a href="https://github.com/daviddoret/punctilious">https://github.com/daviddoret/punctilious</a></p>

## Package directory

The *punctilious* package is available for download from the [Python Package Index (PyPi)](https://pypi.org/) here:
<p align="center"><a href="https://pypi.org/project/punctilious/">https://pypi.org/project/punctilious/</a></p>

## Prerequisites

Python version 3.11 or later.

## Installation

Install the latest version of the *punctilious* package, or upgrade it to the latest version if already installed:

```console
pip install punctilious --upgrade
```

## Getting started

A series of samples will be provided soon once we will have published our documentation on ReadTheDocs. Please wait...

## Documentation

The documentation of the *punctilious* package is hosted on [ReadTheDocs](https://docs.readthedocs.io/) here:
<p align="center"><a href="https://punctilious.readthedocs.io/en/latest/">https://punctilious.readthedocs.io/en/latest/</a></p>

## More links

* [Roadmap](https://punctilious.readthedocs.io/en/latest/front_matter/roadmap_front_matter.html)
* [Contributing](https://punctilious.readthedocs.io/en/latest/front_matter/contributing_front_matter.html)
* [Project](https://punctilious.readthedocs.io/en/latest/front_matter/project_front_matter.html)
* [License](https://github.com/daviddoret/punctilious/blob/master/LICENSE)

## Acknowledgments

The list of dependencies is being compiled. Please wait...
